modules
=======

All modules in idiscore


idiscore.annotation module
--------------------------

.. automodule:: idiscore.annotation
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.bouncers module
------------------------

.. automodule:: idiscore.bouncers
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.core module
--------------------

.. automodule:: idiscore.core
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.dataset module
-----------------------

.. automodule:: idiscore.dataset
   :members:
   :undoc-members:
   :show-inheritance:


idiscore.defaults module
------------------------

.. automodule:: idiscore.defaults
   :members:
   :undoc-members:
   :show-inheritance:


idiscore.delta module
---------------------

.. automodule:: idiscore.delta
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.exceptions module
--------------------------

.. automodule:: idiscore.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.identifiers module
---------------------------

.. automodule:: idiscore.identifiers
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.imageprocessing module
-------------------------------

.. automodule:: idiscore.image_processing
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.insertions module
--------------------------

.. automodule:: idiscore.insertions
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.nema module
--------------------

.. automodule:: idiscore.nema
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.operators module
-------------------------

.. automodule:: idiscore.operators
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.privateprocessing module
---------------------------------

.. automodule:: idiscore.private_processing
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.rule\_sets module
--------------------------

.. automodule:: idiscore.rule_sets
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.rules module
---------------------

.. automodule:: idiscore.rules
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.settings module
------------------------

.. automodule:: idiscore.settings
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.templates module
-------------------------

.. automodule:: idiscore.templates
   :members:
   :undoc-members:
   :show-inheritance:

idiscore.validation module
--------------------------

.. automodule:: idiscore.validation
   :members:
   :undoc-members:
   :show-inheritance:


.. toctree::
   :maxdepth: 4


